Lua_CircleList = class("Lua_CircleList", Lua_DisplayObject)
function Lua_CircleList:ctor(p, rw, rh)
	self.rectWidth = rw
	self.rectHeight = rh
	self.cellsCount = 0

	self.r_small = 3 -- 小圆半径
	self.r_big = 5 -- 大圆半径
	self.angle = 0 -- 决定起始位置
	self.changeScale = 1
	self.moveSpd = 100
	self.minY = 0
	self.maxY = 0
	self.regulateTime = 0.3

	self.showList = Array()
	self:superCall("ctor", p)
end

function Lua_CircleList:buildShowItem()
	self:superCall("buildShowItem")
	self:setRectSize(self.rectWidth, self.rectHeight)

	self.mask = UICreate.createUIMaskContainer(self.content, nil, nil, 0, 0, 0, 0)
	self.mask:setAnchorMin(0, 0)
	self.mask:setAnchorMax(1, 1)
	self.mask:setSubRectPivot(0.5, 0.5)
	self.mask:setColor(0, 0, 0, 1)
	self.mask.clickScale = false
	self.mask:addRectMask2D()
	self.sub = self.mask.sub

	self.rotImg = UICreate.createUIAtlasImage(self.content, "common_altas_1", "default", 0, 0, self.rectWidth, self.rectHeight)
	self.rotImg.clickScale = false
	self.rotImg:addMousDownFuntion(self,self.onMouseDownFun)
	self.rotImg:addMouseUpFuntion(self,self.onMouseUpFun)
end

function Lua_CircleList:dispose()
	self:stopTimer()
	self:stopRegulate()
	if self.hangObject ~= nil and IsNil(self.hangObject) == false then
		WindowMananger.getInstance():returnToPool(self.hangObject.transform)
		UnityEngine.GameObject.Destroy(self.hangObject)
		self.hangObject = nil
	end
	if self.showList then
		self.showList:dispose()
		self.showList:clear()
		self.showList = nil
	end
	if self.mask then
		self.mask:dispose()
		self.mask = nil
	end
	self.sub = nil
	self.pressItem = nil
	self:superCall("dispose")
end

function Lua_CircleList:setSubPos(posX, posY, posZ)
	LuaUtil.setObjPos(self.sub, posX, posY, posZ)
end

function Lua_CircleList:setRotImg(posX, posY, width, height)
	self.rotImg:setLocation(posX, posY, 0)
	self.rotImg:SetDimensions(width, height)
end

function Lua_CircleList:createHangObject()
	if self.hangObject == nil then
		self.hangObject = UICreate.createGameObject(self.sub, 0, 0, 0)
		self.hangObject:AddComponent(typeof(UnityEngine.RectTransform))
		LuaUtil.setRectSize(self.hangObject, 0, 0)
	end
	self:updateSiblingIndex()
end

function Lua_CircleList:updateSiblingIndex()
	if self.hangObject then
		self.hangObject.transform:SetSiblingIndex(0)

		for i = 1, self.cellsCount do
			if self.showList[i].posY > 0 then
				self.showList[i]:setSiblingIndex(0)
			else
				self.showList[i]:setSiblingIndex(999)
			end
		end
	end
end

function Lua_CircleList:setListCell(cellClass, cellWidth, cellHeight)
	self.cellClass = cellClass
	self.cellWidth = cellWidth
	self.cellHeight = cellHeight
end

function Lua_CircleList:moveToIndex(index, immediately)
	if self.showList[index].angle ~= self.firstAngle then
		self.targetAngle = self.firstAngle - self.showList[index].angle
		if immediately == true then
			self:updateShow(self.targetAngle)
		else
			self:startRegulate()
		end
	end
end

function Lua_CircleList:setSelectClick(index)
	for i = 1, self.cellsCount do
		if self.showList[i].cellIndex == index then
			self.showList[i]:onPressClick()
		end
	end
end

function Lua_CircleList:setSelected(index)
	for i = 1, self.cellsCount do
		if self.showList[i].cellIndex == index then
			self.showList[i]:setSelected(true)
		else
			self.showList[i]:setSelected(false)
		end
	end
end

function Lua_CircleList:setData(data)
	self.firstAngle = nil
	self.cellsCount = 0;

    if data.typeof ~= nil and data:typeof() == "Array" then
        self.cellsCount = data:getSize()
    else
        self.cellsCount = #data
    end

    local num = self.showList:getSize() - self.cellsCount
    local item
    while (num > 0) do
        item = self.showList:remove()
        item:dispose()
        item = nil
        num = num - 1
    end
	
	local radian -- 弧度
	local posX
	local posY
	local angle = self.angle
	local offsetY
	local scale
	local theta = 360 / self.cellsCount -- θ

	radian = (self.angle / 180) * Mathf.PI
	self.minY = self.r_small * Mathf.Sin(radian)

	radian = ((self.angle + 180) / 180) * Mathf.PI
	self.maxY = self.r_small * Mathf.Sin(radian)

	for i = 1, self.cellsCount do
		item = self.showList[i]
		if item == nil then
			item = self.cellClass.new(self.sub)
			self.showList:add(item)
		end
		item:setRectSize(self.cellWidth, self.cellHeight)
		item:setCellIndex(i)
		item:setData(data[i])
		
		offsetY = self:getOffostY(angle)
		radian = (angle / 180) * Mathf.PI
		posX = self.r_big * Mathf.Cos(radian)
		posY = self.r_small * Mathf.Sin(radian)
		item:setLocation(posX, posY + offsetY, 0)

		scale = self:getOffostScale(posY + offsetY)
		item:setScale(scale, scale)

		item:setAngle(angle)
		angle = angle + theta
		if self.firstAngle == nil then
			self.firstAngle = item.angle
		end
	end
	self:updateSiblingIndex()
end

function Lua_CircleList:getOffostY(angle)
	return 0
end

function Lua_CircleList:getOffostScale(posY)
	return ((1 - self.changeScale) / (self.maxY - self.minY)) * (self.maxY - posY) + self.changeScale
end

function Lua_CircleList:onMouseDownFun(go)
	self:onPress(go, true)
end

function Lua_CircleList:onMouseUpFun(go)
	self:onPress(go, false)
end

function Lua_CircleList:onPress(go, state)
	self:stopTimer()
	if state then
		self:stopRegulate()
		self.startMouseX = CommonUtil.mousePositionX
		self.startClickTime = getTime()
		self:startTimer()
	else
		local dx = CommonUtil.mousePositionX - self.startMouseX
		if getTime() - self.startClickTime <= 0.3 and Mathf.Abs(dx) < 2 then
			local pressItem = self:checkClick()
			if pressItem then
				if pressItem.angle ~= self.firstAngle then
					self.targetAngle = self.firstAngle - pressItem.angle
					self:startRegulate()
				end
				pressItem:onPressClick()
				self:setSelected(pressItem.cellIndex)
			end
		else
			self:checkPosFix()
		end
	end
end

function Lua_CircleList:checkClick()
	self.mask:refreshTouchPosInverseSubTf()
	local posX = self.mask.touchSubRectPx
	local posY = self.mask.touchSubRectPy
	for i = 1, self.cellsCount do
		if self.showList[i]:checkInBound(posX, posY) == true then
			return self.showList[i]
		end
	end
	return nil
end

function Lua_CircleList:startTimer()
	if self.bTimer ~= true then
		self.bTimer = true
		self.startTime = getTime()
		self.moveDis = 0
		self:addTimer("Lua_CircleList", 0.01, self, self.onTimer)
	end
end

function Lua_CircleList:stopTimer()
	if self.bTimer == true then
		self.bTimer = false
		self:removeTimer(self, self.onTimer)
	end
end

function Lua_CircleList:onTimer()
	local t = getTime()
	local dt = t - self.startTime -- 时差
	self.startTime = t
	local moveDis = CommonUtil.mousePositionX - self.startMouseX
	if moveDis ~= self.moveDis then
		local value
		if moveDis > self.moveDis then -- 向右移动
			self.isRight = true
			value = self.moveSpd * dt
		else
			self.isRight = false
			value = -self.moveSpd * dt
		end
		self:updateShow(value)
	end
	self.moveDis = moveDis
end

function Lua_CircleList:updateShow(value)
	local item
	local angle
	local radian
	local posX
	local posY
	local offsetY
	local scale
	for i = 1, self.cellsCount do
		item = self.showList[i]
		angle = item.angle + value
		offsetY = self:getOffostY(angle)
		radian = (angle / 180) * Mathf.PI
		posX = self.r_big * Mathf.Cos(radian)
		posY = self.r_small * Mathf.Sin(radian)
		item:setLocation(posX, posY + offsetY, 0)

		scale = self:getOffostScale(posY + offsetY)
		item:setScale(scale, scale)

		item:setAngle(angle)
	end
	self:updateSiblingIndex()
end

function Lua_CircleList:checkPosFix()
	quickSort(self.showList, "angle", true) -- 排序是因为经过旋转后，角度有变化
	if self.isRight then
		for i = 1, self.cellsCount do
			if self.showList[i].angle <= self.firstAngle then
				self.selectIdx = i
			end
		end
	else
		for i = 1, self.cellsCount do
			if self.showList[i].angle > self.firstAngle then
				self.selectIdx = i
				break
			end
		end
	end
	if self.selectIdx then
		self.targetAngle = self.firstAngle - self.showList[self.selectIdx].angle
	end
	self:startRegulate()
end

function Lua_CircleList:startRegulate()
	if self.bRegulate ~= true then
		self.bRegulate = true
		self.startRegulateTime = getTime()
		self:addTimer("Lua_CircleList_Regulate", 0.01, self, self.onRegulate)
	end
end

function Lua_CircleList:stopRegulate()
	if self.bRegulate == true then
		self.bRegulate = false
		self:removeTimer(self, self.onRegulate)
	end
end

function Lua_CircleList:onRegulate()
	local dt = getTime() - self.startRegulateTime
	if dt >= self.regulateTime then
		self:stopRegulate()
		self:updateShow(self.targetAngle)
		if self.selectIdx then
			local index
			for i = 1, self.cellsCount do
				if self.showList[i].angle == self.firstAngle then
					index = self.showList[i].cellIndex
					break
				end
			end
			self:setSelectClick(index)
			self:setSelected(index)
			self.selectIdx = nil
		end
	else
		local value = Mathf.Lerp(0, self.targetAngle, dt / self.regulateTime)
		local item
		local angle
		local radian
		local posX
		local posY
		local offsetY
		local scale
		for i = 1, self.cellsCount do
			item = self.showList[i]
			angle = item.angle + value
			offsetY = self:getOffostY(angle)
			radian = (angle / 180) * Mathf.PI
			posX = self.r_big * Mathf.Cos(radian)
			posY = self.r_small * Mathf.Sin(radian)
			item:setLocation(posX, posY + offsetY, 0)

			scale = self:getOffostScale(posY + offsetY)
			item:setScale(scale, scale)
		end
	end
end




















Lua_CircleItem = class("Lua_CircleItem", Lua_DisplayObject)
function Lua_CircleItem:ctor(p, skin)
	self:superCall("ctor", p, skin, false)
end

function Lua_CircleItem:buildShowItem()
	self:superCall("buildShowItem")
	-- self.angleText = UICreate.createLabel(self.content, nil, 0, 0, 100, 40, 30)
	-- self.angleText.pivotValue = 4
	-- self.angleText.alignmentValue = 4
	-- self.angleText.horizontalOverflowValue = 1
end

function Lua_CircleItem:dispose()
	self:superCall("dispose")
end

function Lua_CircleItem:checkInBound(touchX, touchY)
	local posX = self.posX or 0
	local posY = self.posY or 0
	local scaleX = self.scaleX or 1
	local scaleY = self.scaleY or 1
	local minX = posX - self.w / 2 * scaleX
	local maxX = posX + self.w / 2 * scaleX
	local minY = posY - self.h / 2 * scaleY
	local maxY = posY + self.h / 2 * scaleY
	if touchX >= minX and touchX <= maxX and touchY >= minY and touchY <= maxY then
		return true
	end
	return false
end

function Lua_CircleItem:setAngle(value)
	self._angle = self:checkAngle(value)
	-- self.angleText.text = self._angle
end

function Lua_CircleItem.Get:angle()
	return self._angle == nil and 0 or self._angle
end

function Lua_CircleItem:checkAngle(value)
	while value > 360 do
		value = value - 360
	end
	while value <= 0 do
		value = value + 360
	end
	return Mathf.Floor(value)
end

function Lua_CircleItem:setCellIndex(value)
	self.cellIndex = value
	self.content.name = self.classname..value
end

function Lua_CircleItem:setData(data)

end

function Lua_CircleItem:setSelected(bSelected)

end

function Lua_CircleItem:onPressClick()

end