checkRequire("Lua_RoleAttrItem")
checkRequire("Lua_ArtifactSetItem")
Lua_RolePanel = class("Lua_RolePanel", Lua_DisplayObject);
function Lua_RolePanel:ctor(p)
	self:superCall("ctor", p, "RolePanel_skin");
end

function Lua_RolePanel:buildShowItem()
	self:superCall("buildShowItem");
	self.attrArr = Array()

	self:addLuaEvent("UPDATE_ROLE_INFO", self, self.updateShowInfo);
	self:addLuaEvent("UPDATE_ROLE_FORCE", self, self.updateShowInfo);
	self:addLuaEvent("UPDATE_HERO_LINEUP_INFO", self, self.updateArtifact);
	self:addLuaEvent("ARTIFACT_SET_COMPLETED", self, self.onArtifactUpdate);

	self.btnHelp:addClickFuntion(self, self.onHelpClick)
	self.checkStory:addClickFuntion(self, self.onCheckStory)

	if DataCenter.roleData.bInitRoleData then
		self:updateShowInfo();
	else
		Lua_ProxyManager.getProxy("Lua_RoleProxy"):sRoleInfo();
	end
	self:updateArtifact()
end

function Lua_RolePanel:dispose()
	if self.attrArr then
		self.attrArr:dispose()
		self.attrArr:clear()
		self.attrArr = nil
	end
	if self.latticeArr then
		self.latticeArr:dispose()
		self.latticeArr = nil
	end
    if self.data then
        self.data:initLocalInfo()
        self.data = nil
    end
	self:superCall("dispose");
end

function Lua_RolePanel:updateShowInfo()
	local roleData = DataCenter.roleData;
	self.forceText.text = roleData.leaderForce;

	local vo = DataCenter.roleUtil:getFateVoById(roleData.curFaceId);
	self.fateText.text = LanUtil.formateStr(350004, vo.name, convert_arab_to_chinese(vo.level));

	local arr = DataCenter.attributesUtil:getAttrArrByServer(roleData.prop_list);
	local item
	local posX
	local posY
	for i = 1, arr:getSize() do
		item = self.attrArr[i]
		if item == nil then
			item = Lua_RoleAttrItem.new(self.content)
			self.attrArr:add(item)
		end
		item:setRectAnchor(7)
		posX = -280 + ((i - 1) % 2) * 330
		posY = 467 + Mathf.Floor((i - 1) / 2) * -37
		item:setLocation(posX, posY, 0)
		item:setData(arr[i])
	end

	arr:clear();
	arr = nil;

	local id = DataCenter.artifactData.show_artifact;
	vo = DataCenter.artifactUtil:getArtifactVoById(id);
	Lua_MsgUtil.callFunc("ARTIFACT_SELECT", vo)
end

function Lua_RolePanel:updateArtifact()
	self.lineupType = Lua_HeroUtil.LINEUP_MAIN_TYPE
	self.lineupIdx = 1
	self.data = DataCenter.heroLineupData:getLineupVo(self.lineupType);

	if self.latticeArr == nil then
		self.latticeArr = Array()
	end
	local list = DataCenter.artifactUtil.unlock_level
	local item
	for i = 1, #list do
		item = self.latticeArr[i]
		if item == nil then
			item = Lua_ArtifactSetItem.new(self.content)
			self.latticeArr:add(item)
		end
		item:setDataByLineupType(i, list[i], self.lineupType, self.lineupIdx)
		item:setClick(self, self.onArtifactSet)
	end

	local len = self.latticeArr:getSize()
	local space = 230
	local w = -(space * len) / 2 + space / 2
	for i = 1, len do
		item = self.latticeArr[i]
		item:setRectAnchor(7)
		item:setLocation(((i - 1) % len) * space + w, 307, 0)
	end
end

function Lua_RolePanel:onArtifactSet()
	Lua_WindowUtil.openWin("Lua_ArtifactSetWindow", Lua_WinParam.ACTION_OPEN, self.data.artifactDic[self.lineupIdx])
end

function Lua_RolePanel:onArtifactUpdate()
	if self.data:checkLineupIsChange(self.lineupIdx) then
		Lua_ProxyManager.getProxy("Lua_HeroProxy"):sHeroSaveLineup(self.lineupType, self.data.standTypeDic, self.data.heroDic, self.data.artifactDic)
	end
end

function Lua_RolePanel:onHelpClick(go)
	local tipsData = { des = LanUtil.getValue(350005), posX = 190, posY = -240 };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

function Lua_RolePanel:onCheckStory(go)
	Lua_WindowUtil.openWin("Lua_RaccoonStoryWindow", Lua_WinParam.ACTION_OPEN)
end