-- 炼金工坊
Lua_AlchemyWindow = class("Lua_AlchemyWindow", Lua_Window)
function Lua_AlchemyWindow:ctor()
	self:superCall("ctor");
    
	self.windowName = "Lua_AlchemyWindow";
	self.skinName = "AlchemyWindow_skin";
	self.winBgPath = "/images/common/ui_djf_bg_1.png";
	self.showBlackMask = true;
	self.isClickClose = true;
	self:addPreLoadRes(self.winBgPath, Lua_LoadFileType.IMG);
end

function Lua_AlchemyWindow:buildShowItem()
	self:superCall("buildShowItem");
	self:addLuaEvent("UPDATE_SINGLE_ALCHEMY_INFO", self, self.updateSingleAlchemy);
	self:addLuaEvent("UPDATE_ALCHEMY_INFO", self, self.updateAlchemyInfo);
	self.refreshTime = 0;
	self.itemDic = {}

	self.checkHelp:addClickFuntion(self, self.onCheckHelp);
	self.timesBtn:addClickFuntion(self, self.onGetTimes);

	self.showEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_dj_jb_0001", "ui_dj_jb_0001", 200, 250)
	self.showEff.siblingIndex = 1

	self:updateShowInfo();
	Lua_ProxyManager.getProxy("Lua_RoleProxy"):sAlchemyInfo();
end

function Lua_AlchemyWindow:dispose()
	self:stopTimer();
	if self.showEff then
		self.showEff:dispose()
		self.showEff = nil
	end
	if self.itemDic then
		for k,v in pairs(self.itemDic) do
			v:dispose()
			self.itemDic[k] = nil
		end
		self.itemDic = nil
	end
	self:superCall("dispose");
end

function Lua_AlchemyWindow:updateShowInfo()
	self.timesText.text = LanUtil.formateStr(430005, tostring(DataCenter.personReadData.alchemyNum));
end

function Lua_AlchemyWindow:updateSingleAlchemy(msg)
	if msg == nil then
		return
	end
	self.itemDic[msg.alchemy_info.index]:setData(msg.alchemy_info)
end

function Lua_AlchemyWindow:updateAlchemyInfo(msg)
	if msg == nil then
		return
	end

	local data
	local item
	for i = 1, #msg.alchemy_list do
		data = msg.alchemy_list[i]
		item = self.itemDic[data.index]
		if item == nil then
			item = Lua_AlchemyItem.new(self.content)
			self.itemDic[data.index] = item
		end
		item:setLocation(-223 + (i - 1) * 223, -122.5, 0)
		item:setData(data)
	end

	self.refreshTime = msg.tick
	self:onTimer()
	self:startTimer()
end

function Lua_AlchemyWindow:onCheckHelp(go)
	local tipsData = { needAdapt = false, des = LanUtil.getValue(430004), posX = -165, posY = -20 };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

function Lua_AlchemyWindow:onGetTimes(go)
	DataCenter.funcPathUtil:gotoFunction(1083, true);
end

function Lua_AlchemyWindow:startTimer()
	if self.bTimer ~= true then
		self.bTimer = true;
		self:addTimer("Lua_AlchemyWindow", 1, self, self.onTimer, nil, -1);
	end
end

function Lua_AlchemyWindow:stopTimer()
	if self.bTimer == true then
		self.bTimer = false;
		self:removeTimer(self, self.onTimer);
	end
end

function Lua_AlchemyWindow:onTimer()
	local time = self.refreshTime - DataCenter.roleData.serverTime;
	if time <= 0 then
		self:stopTimer();
		Lua_ProxyManager.getProxy("Lua_RoleProxy"):sAlchemyInfo(); -- 校验数据
		time = 0;
	end
	self.txtTime.text = LanUtil.formateStr(430000, Lua_TimeTransform.transSeconds6(time))
end




















Lua_AlchemyItem = class("Lua_AlchemyItem", Lua_DisplayObject)
function Lua_AlchemyItem:ctor(p)
	self:superCall("ctor", p, "AlchemyItem_skin")
end

function Lua_AlchemyItem:buildShowItem()
	self:superCall("buildShowItem")
	self.btnAlchemy:addClickFuntion(self, self.onAlchemyClick)
end

function Lua_AlchemyItem:dispose()
	self.data = nil
	self.configData = nil
	self:superCall("dispose")
end

function Lua_AlchemyItem:setData(data)
	self.data = data

	self.configData = getConfig("alchemy", data.index)
	self.txtTitle.text = LanUtil.formateStr(430001, tostring(self.configData.profit / 60))
	self.incomeCount.text = data.gold_profit.amount
	self.icon:setAltas("role_atlas", self.configData.icon)
	if data.left_times > 0 then
		self.txtTimes:setEnable(true)
		self.txtTimes.text = LanUtil.formateStr(430002, tostring(data.left_times))
		self.btnAlchemy:setEnable(true)
		self.alchemyImg:setEnable(false)
		if self.configData.free == 1 then
			self.btnAlchemy:setLangValue(430003)
		else
			self.btnAlchemy.label = spliceIconStrById(self.configData.cost[1])..self.configData.cost[2]
		end
	else
		self.txtTimes:setEnable(false)
		self.btnAlchemy:setEnable(false)
		self.alchemyImg:setEnable(true)
	end
end

function Lua_AlchemyItem:onAlchemyClick(go)
	if self.data == nil or self.configData == nil then
		return
	end

	if self.configData.free ~= 1 and not DataCenter.moneyData:isMoneyEnough(self.configData.cost[1], self.configData.cost[2], true, true) then
		return
	end

	Lua_ProxyManager.getProxy("Lua_RoleProxy"):sAlchemy(self.data.index)
end