Lua_ArtifactSetItem = class("Lua_ArtifactSetItem", Lua_DisplayObject)
function Lua_ArtifactSetItem:ctor(p)
	self:superCall("ctor", p, "ArtifactSetItem_skin")
end

function Lua_ArtifactSetItem:buildShowItem()
	self:superCall("buildShowItem")
	self.bg.clickScale = false
end

function Lua_ArtifactSetItem:dispose()
	if self.redPoint then
		self.redPoint:dispose()
		self.redPoint = nil
	end
	self.owner = nil
	self.callBack = nil
	self.downCallBack = nil
	self.upCallBack = nil
	self.data = nil
	self:superCall("dispose")
end

function Lua_ArtifactSetItem:checkInBound(touchX, touchY)
	local posX = self.posX or 0
	local posY = self.posY or 0
	local scaleX = self.scaleX or 1
	local scaleY = self.scaleY or 1
	local minX = posX - self.bg.width / 2 * scaleX
	local maxX = posX + self.bg.width / 2 * scaleX
	local minY = posY - self.bg.height / 2 * scaleY
	local maxY = posY + self.bg.height / 2 * scaleY
	if touchX >= minX and touchX <= maxX and touchY >= minY and touchY <= maxY then
		return true
	end
	return false
end

function Lua_ArtifactSetItem:setDataByLineupType(index, unlockLv, lineupType, lineupIdx)
	local vo = DataCenter.heroLineupData:getLineupVo(lineupType)
	self:setDataByArtifactDic(index, unlockLv, vo.artifactDic, lineupIdx)
end

function Lua_ArtifactSetItem:setDataByArtifactDic(index, unlockLv, artifactDic, lineupIdx)
	self:setDataByArtifactList(index, unlockLv, artifactDic[lineupIdx])

	local artifactId = DataCenter.heroLineupData:getUnWearArtifact(artifactDic, lineupIdx)
	self:showRedDot(DataCenter.roleData.level >= unlockLv and self.data == nil and artifactId ~= nil)
end

function Lua_ArtifactSetItem:setDataByArtifactList(index, unlockLv, artifactArr)
	self.content.name = self.classname..index
	self.index = index
	self.unlockLv = unlockLv
	self.data = nil

	if unlockLv > DataCenter.roleData.level then
		self.bg:setAltas("raccoon_atlas_1", "xui_hx_window_15")
		self.icon:setEnable(false)
		self.levelBg:setEnable(false)
		self.levelText:setEnable(false)
		self.energyIcon:setEnable(false)
		self.energyText:setEnable(false)
	else
		local artifactId = artifactArr[index]
		if artifactId == nil or artifactId == 0 then
			self.bg:setAltas("raccoon_atlas_1", "xui_hx_window_14")
			self.icon:setEnable(false)
			self.levelBg:setEnable(false)
			self.levelText:setEnable(false)
			self.energyIcon:setEnable(false)
			self.energyText:setEnable(false)
		else
			self.data = DataCenter.artifactUtil:getArtifactVoById(artifactId)
			local config = Lua_SkillConfigData.getConfigData(self.data.skill_id)
			if config == nil then
				self.data = nil;
				self.bg:setAltas("raccoon_atlas_1", "xui_hx_window_14")
				self.icon:setEnable(false)
				self.levelBg:setEnable(false)
				self.levelText:setEnable(false)
				self.energyIcon:setEnable(false)
				self.energyText:setEnable(false)
			else
				self.bg:setAltas("raccoon_atlas_1", "xui_hx_window_13")
				self:setDataByArtifactVo(self.data);
			end
		end
	end
end

function Lua_ArtifactSetItem:setDataByArtifactVo(vo)
	self.icon:setEnable(true)
	self.levelBg:setEnable(true)
	self.levelText:setEnable(true)
	self.energyIcon:setEnable(true)
	self.energyText:setEnable(true)

	local config = Lua_SkillConfigData.getConfigData(vo.skill_id)
	self.icon:setAltas(config.atlas, config.sprite)
	self.levelText.text = config.level
	self.energyText.text = config.costEnergy
end

function Lua_ArtifactSetItem:showRedDot(value)
	if value == true then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content)
			self.redPoint:setLocation(35, 38, 0)
			self.redPoint:createRedPointEff()
		end
		self.redPoint:updateRedPointShow(true)
	else
		if self.redPoint then
			self.redPoint:updateRedPointShow(false)
		end
	end
end

function Lua_ArtifactSetItem:setClick(owner, callBack)
	self.owner = owner
	self.callBack = callBack
	if owner == nil or callBack == nil then
		self.bg:removeClickFuntion(self, self.onClick)
	else
		self.bg:addClickFuntion(self, self.onClick)
	end
end

function Lua_ArtifactSetItem:setMousDownUp(owner, downCallBack, upCallBack)
	self.owner = owner
	self.downCallBack = downCallBack
	self.upCallBack = upCallBack
	if downCallBack == nil then
		self.bg:removeMouseDownFuntion(self, self.onMouseDown)
	else
		self.bg:addMousDownFuntion(self, self.onMouseDown)
	end
	if upCallBack == nil then
		self.bg:removeMouseUpFuntion(self, self.onMouseUp)
	else
		self.bg:addMouseUpFuntion(self, self.onMouseUp)
	end
end

function Lua_ArtifactSetItem:onClick(go)
	if self.unlockLv > DataCenter.roleData.level then
		OperateAlert.show(LanUtil.formateStr(350043, tostring(self.unlockLv)))
		return
	end
	if self.owner and self.callBack then
		self.callBack(self.owner)
	end
end

function Lua_ArtifactSetItem:onMouseDown(go)
	if self.data == nil then
		return
	end

	if self.owner and self.downCallBack then
		self.downCallBack(self.owner, self.data)
	end
end

function Lua_ArtifactSetItem:onMouseUp(go)
	if self.data == nil then
		return
	end

	if self.owner and self.upCallBack then
		self.upCallBack(self.owner, self.data)
	end
end