checkRequire("Lua_ArtifactSetItem")
Lua_ArtifactSetWindow = class("Lua_ArtifactSetWindow", Lua_Window);
function Lua_ArtifactSetWindow:ctor()
self:superCall("ctor");
    
    self.windowName = "Lua_ArtifactSetWindow"
    self.skinName = "ArtifactSetWindow_skin"
    self.showBlackMask = true
    self.isClickClose = true
end

function Lua_ArtifactSetWindow:buildShowItem()
    self:superCall("buildShowItem");
    self:addLuaEvent("ARTIFACT_TOUCH_DOWN", self, self.onAddTouchDown)
    self:addLuaEvent("ARTIFACT_TOUCH_UP", self, self.onAddTouchUp)
    self:addLuaEvent("ARTIFACT_SET_SELECT", self, self.onArtifactSet)

    self.listW = 545
    self.listH = 295
    self.showList = Lua_DragList.new(self.content, self.listW, self.listH, Lua_AxisDefine.Vertical)
    self.showList:setLocation(0, 85, 0)
    self.showList:setListCell(Lua_ArtifactSetCell, 110, 145, 4)
    self.showList:setCellSpacing(35, 5)
    self.showList.canDrag = false
    -- self.showList.canLongPress = true
    -- self.showList.longPressLimit = 0.4
end

function Lua_ArtifactSetWindow:dispose()
    self:stopTimer()
    if self.showList then
        self.showList:dispose()
        self.showList = nil
    end
    if self._pressItem then
        self._pressItem:dispose()
        self._pressItem = nil
    end
    self.clickArtifact = nil
    self:superCall("dispose");
end

function Lua_ArtifactSetWindow:hide()
    Lua_MsgUtil.callFunc("ARTIFACT_SET_COMPLETED")
    self:superCall("hide")
end

function Lua_ArtifactSetWindow:showWin(param)
    self:superCall("showWin", param)
    self.showList.customParam = param
    self:updateShowInfo()
    self:updateLattice()
end

function Lua_ArtifactSetWindow:updateLattice()
    if self.latticeArr == nil then
        self.latticeArr = Array()
    end
    local list = DataCenter.artifactUtil.unlock_level
    local item
    for i = 1, #list do
        item = self.latticeArr[i]
        if item == nil then
            item = Lua_ArtifactSetItem.new(self.content)
            self.latticeArr:add(item)
        end
        item:setDataByArtifactList(i, list[i], self.showData)
        item:setMousDownUp(self, self.onRemoveTouchDown, self.onRemoveTouchUp)
    end

    local len = self.latticeArr:getSize()
    local space = 203
    local w = -(space * len) / 2 + space / 2
    for i = 1, len do
        item = self.latticeArr[i]
        item:setLocation(((i - 1) % len) * space + w, -219, 0)
    end
end

function Lua_ArtifactSetWindow:updateShowInfo()
    local arr = Array()
    local data = DataCenter.artifactUtil:getArtifactList()
    local vo
    for i = 1, data:getSize() do
        vo = DataCenter.artifactUtil:getArtifactVoById(data[i])
        if vo.is_activate == 1 then
            arr:add(data[i])
        end
    end
    self.showList:setArrayData(arr)
    self:showNone(arr:getSize() <= 0)
end

function Lua_ArtifactSetWindow:onArtifactSet(data)
    local index = self.showData:indexOf(data.id)
    if index == -1 then
        local list = DataCenter.artifactUtil.unlock_level
        for i = 1, #list do
            if DataCenter.roleData.level >= list[i] and self.showData[i] == 0 then
                index = i
                break
            end
        end
        if index == -1 then
            OperateAlert.showLangValue(350045)
            return
        end
        self.showData[index] = data.id
    else
        self.showData[index] = 0
    end
    self:updateLattice()
    self:updateShowInfo()
end

function Lua_ArtifactSetWindow:onArtifactUpdate()
    if self.clickArtifact then
        if not self.bLongPress then
            local index = self.showData:indexOf(self.clickArtifact.id)
            if index == -1 then
                local list = DataCenter.artifactUtil.unlock_level
                for i = 1, #list do
                    if DataCenter.roleData.level >= list[i] and self.showData[i] == 0 then
                        index = i
                        break
                    end
                end
                if index == -1 then
                    OperateAlert.showLangValue(350045)
                    return
                end
                self.showData[index] = self.clickArtifact.id
            else
                self.showData[index] = 0
            end
            self:updateLattice()
            self:updateShowInfo()
        elseif self._pressItem ~= nil then
            local list = DataCenter.artifactUtil.unlock_level
            for i = 1, #list do
                if self.latticeArr[i]:checkInBound(self._pressItem.x, self._pressItem.y) then
                    if list[i] > DataCenter.roleData.level then
                        OperateAlert.show(LanUtil.formateStr(350043, tostring(list[i])))
                    else
                        local index = self.showData:indexOf(self.clickArtifact.id)
                        if index ~= -1 then
                            self.showData[index] = self.showData[i]
                        end
                        self.showData[i] = self.clickArtifact.id
                    end
                    break
                end
            end
            self:updateLattice()
            self:updateShowInfo()
        end
    end
end

function Lua_ArtifactSetWindow.Get:pressItem()
    if self._pressItem == nil then
        self._pressItem = Lua_ArtifactSetItem.new(self.content)
    end
    self._pressItem:setEnable(true)
    self._pressItem:setDataByArtifactVo(self.clickArtifact)
    return self._pressItem
end

function Lua_ArtifactSetWindow:onAddTouchDown(data)
    self.clickArtifact = data
    self:startTimer()
end

function Lua_ArtifactSetWindow:onAddTouchUp()
    self:stopTimer()
    self:onArtifactUpdate()
    if self._pressItem then
        self._pressItem:setEnable(false)
    end
    self.clickArtifact = nil
end

function Lua_ArtifactSetWindow:onRemoveTouchDown(data)
    self.clickArtifact = data
    if data ~= nil then
        self:startTimer()
    end
end

function Lua_ArtifactSetWindow:onRemoveTouchUp()
    self:stopTimer()
    -- if not self.bLongPress and self.clickArtifact then
    --     for i = 1, self.showData:getSize() do
    --         if self.showData[i] == self.clickArtifact.id then
    --             self.showData[i] = 0
    --         end
    --     end
    --     self:updateLattice()
    --     self:updateShowInfo()
    -- end
    self:onArtifactUpdate()
    if self._pressItem then
        self._pressItem:setEnable(false)
    end
    self.clickArtifact = nil
end

function Lua_ArtifactSetWindow:startTimer()
    if self.bTimer ~= true then
        self.bTimer = true
        self.bLongPress = false
        self.startClickTime = getTime()
        self.startMouseX = CommonUtil.mousePositionX
        self.startMouseY = CommonUtil.mousePositionY
        self:addTimer("Lua_ArtifactSetWindow", 0.01, self, self.onTimer)
    end
end

function Lua_ArtifactSetWindow:stopTimer()
    if self.bTimer == true then
        self.bTimer = false
        self:removeTimer(self, self.onTimer)
    end
end

function Lua_ArtifactSetWindow:onTimer()
    local dx = CommonUtil.mousePositionX - self.startMouseX
    local dy = CommonUtil.mousePositionY - self.startMouseY
    if Mathf.Abs(dx) > 2 or Mathf.Abs(dy) > 2 then
        local winPos = LuaUtil.getTouchPosInverseObj(self.content)
        self.pressItem:setLocation(winPos.x, winPos.y, 0)
    end
    if getTime() - self.startClickTime > 0.3 then
        self.bLongPress = true
        if Mathf.Abs(dx) <= 2 and Mathf.Abs(dy) <= 2 then
            self:stopTimer()
            if self._pressItem then
                self._pressItem:setEnable(false)
            end
            Lua_WindowUtil.openWin("Lua_ArtifactSkillTipsWindow", Lua_WinParam.ACTION_OPEN, self.clickArtifact.skill_id)
        end
    else
        self.bLongPress = false
    end
end

function Lua_ArtifactSetWindow:showNone(bShow)
    if bShow then
        if self.noneIcon == nil then
            self.noneIcon = UICreate.createImage(self.content, "/images/common/xui_common_widget_020.png", 0, 85, 0, 0);
            self.noneIcon:setScale(0.6, 0.6)

            self.noneText = UICreate.createLabel(self.content, nil, 0, 46, 100, 40, 30);
            self.noneText.pivotValue = 4;
            self.noneText.fontName = Lua_MyUISettings.huakangFontName;
            self.noneText.alignmentValue = 4;
            self.noneText.horizontalOverflowValue = 1;
            self.noneText.colorStr = Lua_ColorDefine.transColorStr("7A6C74");
            self.noneText:setLangValue(350044);
        end
        self.noneIcon:setEnable(true);
        self.noneText:setEnable(true);
    else
        if self.noneIcon then
            self.noneIcon:setEnable(false);
            self.noneText:setEnable(false);
        end
    end
end

-- 检测引导数据
function Lua_ArtifactSetWindow:checkWinGuide()
    self:superCall("checkWinGuide");
end

-- 引导同步
function Lua_ArtifactSetWindow:updateGuide(guideId, info)
    if info == nil then
        return;
    end

    local operateVal = info.operateVal; -- 操作行为参数
    if operateVal == nil then
        return;
    end

    Lua_MsgUtil.callFunc("ARTIFACT_GUIDING_OPEN", true);
    if operateVal == 1 then -- 神器卡槽位是否有神器
        local lineupType = info.lineupType;
        if lineupType == nil then
            return false;
        end
        local teamIdx = info.teamIdx ~= nil and tonumber(info.teamIdx) or 1;
        local artifactPos = info.artifactPos ~= nil and tonumber(info.artifactPos) or 1;
        local artifactId = DataCenter.heroLineupData:getLineupArtifact(lineupType, teamIdx, artifactPos);
        if artifactId == 0 then
            local arr = self.showList.showDragDataList;
            local item;
            if info.artifactId ~= nil then
                for i = 1, arr:getSize() do
                    item = arr:getItem(i).cell;
                    if item.artifactId == info.artifactId then
                        DataCenter.guideCommonData.guideClickObjTarget = item.content;
                        Lua_MsgUtil.callFunc("Guide_WinSync_Complete", guideId);
                        break;
                    end
                end
            end
        else
            DataCenter.guideCommonData.winGuideResult = 1;
            Lua_MsgUtil.callFunc("Guide_WinSync_Complete", guideId);
        end
    end
end





















Lua_ArtifactSetCell = class("Lua_ArtifactSetCell", Lua_ListCell)
function Lua_ArtifactSetCell:ctor(p)
    self:superCall("ctor", p)
end

function Lua_ArtifactSetCell:buildShowItem()
    self:superCall("buildShowItem")

    self.skillItem = Lua_SkillIconItem.new(self.content)
    self.skillItem:setLocation(0, 15, 0)
    self:addLuaEvent("ARTIFACT_GUIDING_OPEN", self, self.setArtifactGuidingState) -- 引导用
end

function Lua_ArtifactSetCell:dispose()
    if self.skillItem then
        self.skillItem:dispose()
        self.skillItem = nil
    end
    self.customParam = nil
    self.data = nil
    self:superCall("dispose")
end

function Lua_ArtifactSetCell:setCustomParam(customParam)
    self.customParam = customParam
end

function Lua_ArtifactSetCell:setData(data)
    self.artifactId = data; -- 引导用
    self.data = DataCenter.artifactUtil:getArtifactVoById(data)
    
    self.skillItem:setSkillId(self.data.skill_id)
    self.skillItem:showName(self.data.color)
    self:setSelected(self.customParam and self.customParam:indexOf(data) ~= -1)
end

function Lua_ArtifactSetCell:setSelected(bValue)
    if bValue then
        if self.selectedIcon == nil then
            self.selectedIcon = UICreate.createUIAtlasImage(self.content, "raccoon_atlas_2", "xui_hx_title_4", 0, 10, 0, 0)
        end
        self.selectedIcon:setEnable(true)
    else
        if self.selectedIcon then
            self.selectedIcon:setEnable(false)
        end
    end
end

function Lua_ArtifactSetCell:setArtifactGuidingState(openState)
    self.guideState = openState;
end

function Lua_ArtifactSetCell:onPressClick()
    if self.guideState then
        Lua_MsgUtil.callFunc("ARTIFACT_SET_SELECT", self.data)
        Lua_MsgUtil.callFunc("LineUp_Actifact_LocationInfo_Update");
    end
end

-- function Lua_ArtifactSetCell:onLongPressClick()
--     Lua_WindowUtil.openWin("Lua_ArtifactSkillTipsWindow", Lua_WinParam.ACTION_OPEN, self.data.skill_id)
-- end

function Lua_ArtifactSetCell:onMouseDownHandle()
    if not self.guideState then
        Lua_MsgUtil.callFunc("ARTIFACT_TOUCH_DOWN", self.data) 
    end
end

function Lua_ArtifactSetCell:onMouseUpHandle()
    if not self.guideState then
        Lua_MsgUtil.callFunc("ARTIFACT_TOUCH_UP")
    end
end