checkRequire("Lua_ArtifactIconItem")
Lua_ArtifactUpStarWindow = class("Lua_ArtifactUpStarWindow", Lua_Window)
function Lua_ArtifactUpStarWindow:ctor()
	self:superCall("ctor")

	self.windowName = "Lua_ArtifactUpStarWindow"
	self.skinName = "ArtifactUpStarWindow_skin"
	self.showBlackMask = true
	self.isClickClose = true;
end

function Lua_ArtifactUpStarWindow:buildShowItem()
	self:superCall("buildShowItem")
	self:addLuaEvent("UPDATE_SINGLE_ARTIFACT_INFO", self, self.updateShowInfo)

	self.cost_icon:addClickFuntion(self, self.onChipClick)
	self.checkCost:addClickFuntion(self, self.onCheckCost)
	self.btnUpStar:addClickFuntion(self, self.onUpStarClick)

	self.curItem = Lua_ArtifactIconItem.new(self.content)
	self.curItem:setLocation(-167.5, 226, 0)

	self.curSkill = Lua_SkillIconItem.new(self.content)
	self.curSkill:setLocation(-155.5, -144, 0)
	self.curSkill:setCanClick(true)
end

function Lua_ArtifactUpStarWindow:dispose()
	if self.curItem then
		self.curItem:dispose()
		self.curItem = nil
	end
	if self.nextItem then
		self.nextItem:dispose()
		self.nextItem = nil
	end
	if self.curSkill then
		self.curSkill:dispose()
		self.curSkill = nil
	end
	if self.nextSkill then
		self.nextSkill:dispose()
		self.nextSkill = nil
	end
	if self.attrList then
		self.attrList:dispose()
		self.attrList:clear()
		self.attrList = nil
	end
	self:superCall("dispose")
end

function Lua_ArtifactUpStarWindow:showWin(param)
	self:superCall("showWin", param)
	self:updateShowInfo()
end

function Lua_ArtifactUpStarWindow:updateShowInfo()
	self.curItem:setData(self.showData)

	self.curSkill:setSkillId(self.showData.skill_id)
	self.curSkill:showName(self.showData.color)

	if self.showData.bMaxStar then
		self.nextObject:SetActive(false)
		self.maxText:setEnable(true)
		self.curItem:setLocation(0, 226, 0)
		self.curSkill:setLocation(0, -144, 0)

		local arr = DataCenter.attributesUtil:getAttrArrByConfig(self.showData.starConfig)
		self:showAttributes(arr)
	else
		self.nextObject:SetActive(true)
		self.maxText:setEnable(false)
		self.curItem:setLocation(-167.5, 226, 0)
		self.curSkill:setLocation(-155.5, -144, 0)

		if self.nextItem == nil then
			self.nextItem = Lua_ArtifactIconItem.new(self.nextObject)
			self.nextItem:setLocation(167.5, 226, 0)
		end
		local starConfig = DataCenter.artifactUtil:getStarConfig(self.showData.star_id + 1)
		self.nextItem:setData(self.showData)
		self.nextItem:showStar(starConfig.star)

		local arr = DataCenter.attributesUtil:getAttrArrByConfig(self.showData.starConfig, starConfig)
		self:showAttributes(arr)

		if self.nextSkill == nil then
			self.nextSkill = Lua_SkillIconItem.new(self.nextObject)
			self.nextSkill:setLocation(155.5, -144, 0)
			self.nextSkill:setCanClick(true)
		end
		self.nextSkill:setSkillId(starConfig.unlock_skill)
		self.nextSkill:showName(self.showData.color)

		local cost = self.showData.starConfig.star_up_cost
		local id = cost[1][1]
		local config = getConfig("item", id)
		self.cost_icon.name = id
		self.cost_icon:setAltas(config.atlas, config.sprite)
		self.cost_icon:resetSize()
		self.cost_icon:setScale(0.35, 0.35, 1)

		local maxValue = cost[1][2]
		local value = DataCenter.packData:getItemCountById(cost[1][1])
		if value >= maxValue then
			self.costText.text = LanUtil.formateStr(10044, Lua_ColorDefine.getColorStr("479154", value), tostring(maxValue))
		else
			self.costText.text = LanUtil.formateStr(10044, Lua_ColorDefine.getColorStr("EF4B30", value), tostring(maxValue))
		end
	end
end

function Lua_ArtifactUpStarWindow:showAttributes(arr)
	if self.attrList == nil then
		self.attrList = Array()
	end
	local len = self.attrList:getSize()
	local dataLen = arr:getSize()
	local maxLen = dataLen > len and dataLen or len
	local item
	for i = 1, maxLen do
		item = self.attrList[i]
		if i > dataLen then
			if item then
				item:setEnable(false)
			end
		else
			if item == nil then
				item = Lua_ArtifactUpStarAttrItem.new(self.content)
				self.attrList:add(item)
			else
				item:setEnable(true)
			end
			item:setLocation(0, 70 - (i - 1) * 55, 0)
			item:setData(i, arr[i])
		end
	end
end

function Lua_ArtifactUpStarWindow:onChipClick(go)
	local id = tonumber(go.name)
	DataCenter.packUtil:openPathWindow(id, false)
end

function Lua_ArtifactUpStarWindow:onCheckCost(go)
	DataCenter.packUtil:openPathWindow(self.showData.starConfig.star_up_cost[1][1], false)
end

function Lua_ArtifactUpStarWindow:onUpStarClick(go)
	local costId = DataCenter.packData:checkConsumeEnough(self.showData.starConfig.star_up_cost)
	if costId == nil then
		Lua_ProxyManager.getProxy("Lua_ArtifactProxy"):sUnStar(self.showData.id)
	else
		DataCenter.packUtil:openPathWindow(costId, false)
	end
end




















Lua_ArtifactUpStarAttrItem = class("Lua_ArtifactUpStarAttrItem", Lua_DisplayObject)
function Lua_ArtifactUpStarAttrItem:ctor(p)
	self:superCall("ctor", p, "ArtifactUpStarAttrItem_skin")
end

function Lua_ArtifactUpStarAttrItem:buildShowItem()
	self:superCall("buildShowItem")
end

function Lua_ArtifactUpStarAttrItem:dispose()
	self:superCall("dispose")
end

function Lua_ArtifactUpStarAttrItem:setData(index, data)
	self.attrIcon:setAltas("common_altas_2", data.hero_attr_icon)
	self.nameText.text = data.show_name
	self.nameText:resetSize()
	self.curText.text = data.showValue
	if data.nextValue and data.nextValue > 0 then
		self.attrIcon:setLocation(-258, 0, 0)
		self.nameText:setLocation(-234, 0, 0)
		self.curText:setLocation(-154, -2.5, 0)
		self.arrow:setEnable(true)
		self.nextText:setEnable(true)
		self.nextText.text = data.showNextValue
	else
		self.attrIcon:setLocation(-95, 0, 0)
		self.nameText:setLocation(-69.5, 0, 0)
		self.curText:setLocation(10, -2.5, 0)
		self.arrow:setEnable(false)
		self.nextText:setEnable(false)
	end
end