-- 命格
checkRequire("Lua_RoleAttrItem")
Lua_RoleFatePanel = class("Lua_RoleFatePanel", Lua_DisplayObject);
function Lua_RoleFatePanel:ctor(p)
	self:superCall("ctor", p, "RoleFatePanel_skin");
end

function Lua_RoleFatePanel:buildShowItem()
	self:superCall("buildShowItem");
	self.isOneKey = false;
	self.chipPos = {{-264, -527}, {-136, -255}, {128, -255}, {257, -527}, {0, -492}};
	self.chipArr = Array();
	self.attrArr = Array();

	self.redPoint = Lua_RedPointIcon.new(self.content, Lua_RedPointList.Fate);
	self.redPoint:setRectAnchor(7);
	self.redPoint:setLocation(90, 695);

    self.itemList = Lua_DragList.new(self.content, 700, 115, Lua_AxisDefine.Horizontal);
    self.itemList:setRectAnchor(7);
    self.itemList:setLocation(0, 515, 0);
    self.itemList:setListCell(Lua_RoleFateItem, 115, 115, 1);
    self.itemList:setCellSpacing(30, 0);
    
	self:addLuaEvent("UPDATE_FATE_INFO", self, self.updateShowInfo);
	self:addLuaEvent("FATE_ITEM_SELECT", self, self.onFateItemSelect);
	if DataCenter.roleData.bInitFateData then
		self:updateShowInfo();
	else
		Lua_ProxyManager.getProxy("Lua_RoleProxy"):sFateInfo();
	end

	self.btnHelp:addClickFuntion(self, self.onHelpBtnClick);
	self.btnActivate:addClickFuntion(self, self.onActivateBtnClick);
end

function Lua_RoleFatePanel:dispose()
	Lua_CommonUtil.removeTimer(self, self.updateInfo);
	if self.attrArr then
		self.attrArr:dispose()
		self.attrArr:clear()
		self.attrArr = nil
	end
	if self.redPoint ~= nil then
		self.redPoint:dispose();
		self.redPoint = nil;
	end
	if self.fateArr ~= nil then
		self.fateArr:clear();
		self.fateArr = nil;
	end
	if self.costArr ~= nil then
		self.costArr:dispose();
		self.costArr:clear();
		self.costArr = nil;
	end
	if self.chipArr ~= nil then
		self.chipArr:dispose();
		self.chipArr:clear();
		self.chipArr = nil;
	end
	if self.chipPos then
		table.clear(self.chipPos);
		self.chipPos = nil;
	end
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	if self.rItem ~= nil then
		self.rItem:dispose();
		self.rItem = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_RoleFatePanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);
end

function Lua_RoleFatePanel:updateShowInfo()
	local curFaceId = DataCenter.roleData.curFaceId;
	if self.data == nil then
		self:updateShow(curFaceId);
	else
		self:playEff();
	end
	self:updateAttr();
end

function Lua_RoleFatePanel:updateShow(curFaceId)
	self.curFaceId = curFaceId;
	self.fateArr = DataCenter.roleUtil:getFateArr(curFaceId);
	self.itemList:setArrayData(self.fateArr);
	
	local index;
	for i = 1, self.fateArr:getSize() do
		if self.fateArr[i] == curFaceId then
			index = i;
			break;
		end
	end
	index = index or 1
	self.itemList:moveToIndex(index - 2, true);
	self.itemList:setSelected(index);
	self.itemList:setSelectClick(index);
end

function Lua_RoleFatePanel:updateAttr()
	local arr = DataCenter.attributesUtil:getAttrArrByServer(DataCenter.roleData.destiny_prop);
	local len = arr:getSize()
	local item
	local posX
	local posY
	for i = 1, len do
		item = self.attrArr[i]
		if item == nil then
			item = Lua_RoleAttrItem.new(self.content)
			self.attrArr:add(item)
		end
		item:setRectAnchor(7)
		posX = -280 + ((i - 1) % 2) * 330
		posY = 380 + Mathf.Floor((i - 1) / 2) * -37
		item:setLocation(posX, posY, 0)
		item:setData(arr[i])
	end

	local curFaceId = DataCenter.roleData.curFaceId;
	local vo = DataCenter.roleUtil:getFateVoById(curFaceId);
	local chipId = vo.id * 100 + vo.level;
	local chipData = DataCenter.roleUtil:getFateChipConfig(chipId);
	arr = DataCenter.attributesUtil:getAttrArrByDic(chipData.hero_list);
	for i = 1, arr:getSize() do
		item = self.attrArr[len + i]
		if item == nil then
			item = Lua_RoleAttrItem.new(self.content)
			self.attrArr:add(item)
		end
		item:setRectAnchor(7)
		posX = -280 + ((i - 1) % 2) * 330
		posY = 237 + Mathf.Floor((i - 1) / 2) * -37
		item:setLocation(posX, posY, 0)
		item:setData(arr[i])
	end
	
	arr:clear();
	arr = nil;
end

function Lua_RoleFatePanel:onFateItemSelect(data)
	self.data = data;

	self:updateChips(data);

	local vo = DataCenter.roleUtil:getFateVoById(data.id);
	self.nameText.text = vo.name;

	local chipId;
	if vo.level >= #vo.chips then
		chipId = vo.id * 100 + #vo.chips;
	else
		chipId = vo.id * 100 + vo.level + 1;
	end
	local chipData = DataCenter.roleUtil:getFateChipConfig(chipId);
	local bActivate = DataCenter.roleUtil:checkFateChipIsActivate(chipData.destiny_id, chipData.index);
	if bActivate then
		self.redPoint:setEnable(false);
		self.btnActivate:setMouseEnable(false);
		self.btnActivate:setStyle(3);
		self.btnActivate:setLangValue(350010);
		self.promptText:setEnable(false);
		self:showConsumeItem(nil);
	else
		self.redPoint:setEnable(true);
		self.btnActivate:setStyle(1);

		if chipData.level > DataCenter.roleData.level then
			self.btnActivate:setLangValue(350009);
			self.btnActivate:setMouseEnable(false);
			self.promptText:setEnable(true);
			self.promptText.text = LanUtil.formateStr(350011, tostring(chipData.level));
			self:showConsumeItem(nil);
		else
			self.btnActivate:setMouseEnable(true);
			self.promptText:setEnable(false);
			if self.isOneKey then
				self.btnActivate:setLangValue(350047);
			else
				self.costDic = chipData.cost;
				self.btnActivate:setLangValue(350009);
			end
			self:showConsumeItem(self.costDic);
		end
	end
end

function Lua_RoleFatePanel:showConsumeItem(tab)
	if self.costArr == nil then
		self.costArr = Array();
	end

	local len = self.costArr:getSize();
	if tab == nil then
		len = -len;
	else
		len = table.length(tab) - len;
	end
	while (len > 0) do
		item = Lua_ConsumeIconItem.new(self.content);
		item.joinerStr = " / ";
		item:setStyle(Lua_MyUISettings.defaultFontName, 22, "FFFFFF", 2, "2B3136", 2, 2);
		item:setColorStr("2FC548", "FB524B");
		self.costArr:add(item);
		len = len - 1;
	end

	while (len < 0) do
		item = self.costArr:remove();
		item:dispose();
		len = len + 1;
	end

	len = self.costArr:getSize();
	if len > 0 then
		local space = 300;
		local w = -(space * len) / 2 + space / 2;
		local posX;
		local index = 0;
		for k,v in pairs(tab) do
			index = index + 1

			item = self.costArr[index];
			if type(v) == type_str_number then
				item:setId(k, v);
			else
				item:setData(v)
			end

			posX = ((index - 1) % len) * space + w;
			item:setRectAnchor(7);
			item:setLocation(posX, 606, 0);
		end
	end
end

function Lua_RoleFatePanel:updateChips(data)
	self.costDic = {};
	function setCost(list)
		local id;
		for i = 1, #list do
			id = list[i][1]
			if self.costDic[id] == nil then
				self.costDic[id] = list[i][2]
			else
				self.costDic[id] = self.costDic[id] + list[i][2]
			end
		end	
	end

	local num = #data.chips;
	local len = self.chipArr:getSize();
	local maxLen = num > len and num or len;
	local config;
	local count = 0; -- 未激活数
	for i = 1, maxLen do
		item = self.chipArr[i];
		if i > num then
			if item ~= nil then
				item:setEnable(false);
			end
		else
			if item == nil then
				item = Lua_RoleFateChipItem.new(self.content);
				self.chipArr:add(item);
			end
			item:setEnable(true);
			item:setRectAnchor(1);
			item:setLocation(self.chipPos[i][1], self.chipPos[i][2], 0);
			item:setFinal(i == num);

			config = DataCenter.roleUtil:getFateChipConfig(data.chips[i]);
			item:setData(config);
			if not item.bActivate then
				count = count + 1;
				setCost(config.cost);
			end
		end
	end
	
	if count > 1 then -- 消耗满足当前潜能所有碎片且可激活碎片数量大于1
		local costId = DataCenter.packData:checkConsumeEnough(self.costDic);
		if costId == nil then
			self.isOneKey = true;
		else
			self.isOneKey = false;
		end
	else
		self.isOneKey = false;
	end

	local chipId = data.chips[num];
	local configData = DataCenter.roleUtil:getFateChipConfig(chipId);
	local rewardConfig = Lua_RewardConfigData.getConfigDataById(configData.reward);
	if rewardConfig == nil then
		if self.rItem then
			self.rItem:setArrayData(nil);
		end
	else
		if self.rItem == nil then
			self.rItem = Lua_ItemIconList.new(self.content);
			self.rItem:setLocation(300, 0, 0);
			self.rItem.pivot = -1;
		end
		self.rItem:setArrayData(rewardConfig.rewardsArr);
	end
end

function Lua_RoleFatePanel:playEff()
	self.bPlayNext = false
	local time = 0.2
	if self.isOneKey then
		self.btnActivate:setBtnEnable(false);
		self.redPoint:setEnable(false);
		for i = 1, self.chipArr:getSize() do
			if not self.chipArr[i].bActivate then
				self.bPlayNext = true
				if self.chipArr[i].bFinal then
					time = 1
				end
				self.chipArr[i]:setActivate()
				break
			end
		end
	else
		for i = 1, self.chipArr:getSize() do
			if not self.chipArr[i].bActivate then
				if self.chipArr[i].bFinal then
					time = 1
				end
				self.chipArr[i]:setActivate()
				break
			end
		end
	end
	Lua_CommonUtil.delayCall(time, self, self.updateInfo)
end

function Lua_RoleFatePanel:updateInfo()
	Lua_CommonUtil.removeTimer(self, self.updateInfo);
	if self.bPlayNext ~= true then
		self.btnActivate:setBtnEnable(true);
		local curFaceId = DataCenter.roleData.curFaceId;
		if self.curFaceId == curFaceId then
			self:onFateItemSelect(self.data);
		else
			self:updateShow(curFaceId);
		end
	else
		self:playEff();
	end
end

function Lua_RoleFatePanel:onHelpBtnClick(go)
	local tipsData = { posX = 190, posY = -240, des = LanUtil.getValue(350006) };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

function Lua_RoleFatePanel:onActivateBtnClick(go)
	local costId = DataCenter.packData:checkConsumeEnough(self.costDic);
	if costId == nil then
		if self.isOneKey then
			Lua_ProxyManager.getProxy("Lua_RoleProxy"):sFateActivate(1);
		else
			Lua_ProxyManager.getProxy("Lua_RoleProxy"):sFateActivate(0);
		end
	else
		DataCenter.packUtil:openPathWindow(costId, false);
	end
end




















Lua_RoleFateItem = class("Lua_RoleFateItem", Lua_ListCell);
function Lua_RoleFateItem:ctor(p)
	self:superCall("ctor", p, "RoleFateItem_skin");
end

function Lua_RoleFateItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_RoleFateItem:dispose()
	self.data = nil;
	self:superCall("dispose");
end

function Lua_RoleFateItem:setData(data)
	self.data = DataCenter.roleUtil:getFateVoById(data);
	self.icon:setAltas("raccoon_atlas_1", self.data.iconSprite);
	self.name.text = self.data.name;

	local curFaceId = DataCenter.roleData.curFaceId;
	if self.data.id > curFaceId and self.data.is_activate == 0 then
		self.icon:setGray(true);
		self.name.colorStr = Lua_ColorDefine.transColorStr("D0D0D0");
		self:showLock(true);
	else
		self.icon:setGray(false);
		self.name.colorStr = Lua_ColorDefine.transColorStr("FFFFFF");
		self:showLock(false);
	end
end

function Lua_RoleFateItem:showLock(bShow)
	if bShow then
		if self.lockIcon == nil then
			self.lockIcon = UICreate.createUIAtlasImage(self.content, "common_altas_1", "xui_common_button_023", 0, 0, 0, 0);
			self.lockIcon:setScale(0.8, 0.8, 0.8);
		end
		self.lockIcon:setEnable(true);
	else
		if self.lockIcon ~= nil then
			self.lockIcon:setEnable(false);
		end
	end
end

function Lua_RoleFateItem:onSelectionChange(bSelect)
	self:superCall("onSelectionChange", bSelect);
	self.selectIcon:setEnable(bSelect);
end

function Lua_RoleFateItem:onPressClick()
	local curFaceId = DataCenter.roleData.curFaceId;
	if self.data.id > curFaceId and self.data.is_activate == 0 then
		OperateAlert.showLangValue(350012);
		return false;
	end

	Lua_MsgUtil.callFunc("FATE_ITEM_SELECT", self.data);
	return true;
end






















Lua_RoleFateChipItem = class("Lua_RoleFateChipItem", Lua_DisplayObject);
function Lua_RoleFateChipItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_RoleFateChipItem:buildShowItem()
	self:superCall("buildShowItem");
	self.showPoxY = -50
	self.attrArr = Array();
	self.chipIcon = UICreate.createUIAtlasImage(self.content, nil, nil, 0, 0, 0, 0)
	self.showContainer = Lua_WindowUtil.createContaner(self.content, Vector3.zero)
end

function Lua_RoleFateChipItem:dispose()
	Lua_CommonUtil.removeTimer(self, self.updateData);
	if self.attrArr then
		self.attrArr:dispose()
		self.attrArr:clear()
		self.attrArr = nil
	end
	if self.uiEff then
		self.uiEff:dispose()
		self.uiEff = nil
	end
    if self.showContainer and IsNil(self.showContainer) == false then
        UnityEngine.GameObject.Destroy(self.showContainer);
        self.showContainer = nil;
    end
	self:superCall("dispose");
end

function Lua_RoleFateChipItem:setFinal(bFinal)
	self.bFinal = bFinal;
	if bFinal then
		self.showPoxY = -77
	else
		self.showPoxY = -50
	end
end

function Lua_RoleFateChipItem:setData(data)
	self.data = data;
	self.bActivate = DataCenter.roleUtil:checkFateChipIsActivate(self.data.destiny_id, self.data.index);

	self.chipIcon:setAltas("raccoon_atlas_1", data.icon_sprite);
	self.chipIcon:resetSize();
	self:updateData();
end

function Lua_RoleFateChipItem:updateData()
	self.chipIcon:setGray(self.bActivate == false);

	if self.data then
		if self.data.leader ~= nil then
			self:showAttr(self.bActivate, self.data.color_str, 1, self.data.leader)
		elseif self.data.hero ~= nil then
			self:showAttr(self.bActivate, self.data.color_str, 2, self.data.hero)
		end
	end
end

function Lua_RoleFateChipItem:showAttr(bActivate, colorStr, value, attr)
	for i = 1, self.attrArr:getSize() do
		self.attrArr[i]:setEnable(false)
	end
	local vo
	local index = 1
	local item
	local width = 0
	for k,v in pairs(attr) do
		if v > 0 then
			vo = DataCenter.attributesUtil:createAttrVo(k);
			vo.value = v;
			item = self.attrArr[index]
			if item == nil then
				item = Lua_SpliceTextItem.new(self.showContainer)
				item.pivot = 1
				item.spaceWidth = 5
				self.attrArr:add(item)
			end
			item:setEnable(true)
			if self.bFinal == true then
				if bActivate then
					item:setLeftStyle(Lua_MyUISettings.huakangFontName, 28, colorStr, 2, "202A47", 2, 2)
					item:setRightStyle(Lua_MyUISettings.fangzhengFontName, 24, "FFFFFF", 2, "202A47", 2, 2)
				else
					item:setLeftStyle(Lua_MyUISettings.huakangFontName, 28, "B4B4B6", 2, "202A47", 2, 2)
					item:setRightStyle(Lua_MyUISettings.fangzhengFontName, 24, "B4B4B6", 2, "202A47", 2, 2)
				end
			else
				if bActivate then
					item:setLeftStyle(Lua_MyUISettings.huakangFontName, 22, colorStr, 2, "202A47", 2, 2)
					item:setRightStyle(Lua_MyUISettings.fangzhengFontName, 18, "FFFFFF", 2, "202A47", 2, 2)
				else
					item:setLeftStyle(Lua_MyUISettings.huakangFontName, 22, "B4B4B6", 2, "202A47", 2, 2)
					item:setRightStyle(Lua_MyUISettings.fangzhengFontName, 18, "B4B4B6", 2, "202A47", 2, 2)
				end
			end
			if index == 1 then
				if value == 1 then
					item:setData(LanUtil.formateStr(350007, vo.show_name), string.format("%s%s", "+", vo.showValue))
				else
					item:setData(LanUtil.formateStr(350008, vo.show_name), string.format("%s%s", "+", vo.showValue))
				end
			else
				if bActivate then
					item:setData(string.format("%s%s", "<color=#FFFFFF>、</color>", vo.show_name), string.format("%s%s", "+", vo.showValue))
				else
					item:setData(string.format("%s%s", "<color=#B4B4B6>、</color>", vo.show_name), string.format("%s%s", "+", vo.showValue))
				end
			end
			item:setLocation(width, 0, 0)
			width = width + item.totalWidth
			index = index + 1
		end
	end
	LuaUtil.setObjPos(self.showContainer, -width / 2, self.showPoxY, 0);
end

function Lua_RoleFateChipItem:setActivate()
	self.bActivate = true
	self:showEff(true)
	Lua_CommonUtil.delayCall(0.1, self, self.updateData)
end

function Lua_RoleFateChipItem:showEff(bValue)
	if bValue then
		if self.uiEff == nil then
			if self.bFinal then
				self.uiEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_hx_dqnjh_0101", "ui_hx_dqnjh_0101", 0, 0)
			else
				self.uiEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_hx_xqnjh_0101", "ui_hx_xqnjh_0101", 0, 0)
			end
			self.uiEff.siblingIndex = 1
		else
			if self.bFinal then
				self.uiEff:setUrl("/effects/uiEffects/ui_hx_dqnjh_0101", "ui_hx_dqnjh_0101");
			else
				self.uiEff:setUrl("/effects/uiEffects/ui_hx_xqnjh_0101", "ui_hx_xqnjh_0101");
			end
			self.uiEff:setEnable(false)
			self.uiEff:setEnable(true)
		end
	else
		if self.uiEff then
			self.uiEff:setEnable(false)
		end
	end
end