Lua_RenameWindow = class("Lua_RenameWindow", Lua_Window)
function Lua_RenameWindow:ctor()
	self:superCall("ctor")

	self.windowName = "Lua_RenameWindow"
	self.skinName = "RenameWindow_skin"
	self.showBlackMask = true
	self.isClickClose = true
end

function Lua_RenameWindow:buildPanel(go)
	self:superCall("buildPanel", go)
	self:addLuaEvent("UPDATE_RENAME_INFO", self, self.updateShowInfo)
end

function Lua_RenameWindow:buildShowItem()
	self:superCall("buildShowItem")
	self.renameTime = 0
	self.renameFree = false

	local nameLimit = Lua_CommonUtil.getCommonConfig("name_character_limit", 3)
	self.nameInput:setDefaultLangValue(300021)
	self.nameInput.characterLimit = nameLimit[2]
    self.nameInput.bCheckChinese = true
    self.nameInput:addValidateInfo('A', 'Z')
    self.nameInput:addValidateInfo('a', 'z')
    self.nameInput:addValidateInfo('0', '9')
    self.nameInput:ActivateInputField()

	self.btnCancel:addClickFuntion(self, self.hide)
	self.btnConfirm:addClickFuntion(self, self.onConfirmClick)

	Lua_ProxyManager.getProxy("Lua_RoleProxy"):sRenameInfo()
end

function Lua_RenameWindow:dispose()
	self:endTimer()
	self:superCall("dispose")
end

function Lua_RenameWindow:updateShowInfo(msg)
	if msg == nil then
		return
	end

	if tonumber(msg.last_rename_tick) > 0 then
		local hour = DataCenter.roleUtil.rename_interval
		self.renameTime = (tonumber(msg.last_rename_tick) + hour * 3600) - DataCenter.roleData.serverTime
	end

	local times = DataCenter.roleUtil.rename_free_times
	if msg.rename_num >= times then
		self.renameFree = false
		local cost = DataCenter.roleUtil.rename_consume
		local str = spliceIconStrById(cost[1])
		self.promptText.text = LanUtil.formateStr(300023, tostring(cost[2]), str)
	else
		self.renameFree = true
		self.promptText:setLangValue(300022)
	end

	if self.renameTime > 0 then
		self:startTimer()
		self:onTimer()
	else
		self:endTimer()
		self.timeText.text = nil
	end
end

function Lua_RenameWindow:startTimer()
    if self.bTiming ~= true then
        self.bTiming = true
        self:addTimer("Lua_RenameWindow", 1, self, self.onTimer, nil, -1)
    end
end

function Lua_RenameWindow:endTimer()
    if self.bTiming == true then
        self.bTiming = false
        self:removeTimer(self, self.onTimer)
    end
end

function Lua_RenameWindow:onTimer()
	if self.renameTime > 0 then
		self.renameTime = self.renameTime - 1
		self.timeText.text = Lua_TimeTransform.transSeconds6(self.renameTime)
		self.btnConfirm:setStyle(6)
		self.btnConfirm:setMouseEnable(false)
	else
		self:endTimer()
		self.timeText.text = nil
		self.btnConfirm:setStyle(1)
		self.btnConfirm:setMouseEnable(true)
	end
end

function Lua_RenameWindow:onConfirmClick(go)
	if not self.renameFree then
		local cost = DataCenter.roleUtil.rename_consume
		local haveNum = DataCenter.packData:getItemCountById(cost[1])
		if haveNum < cost[2] then
			DataCenter.packUtil:openPathWindow(cost[1])
			return
		end
	end

	local name = self.nameInput.text
	if name == DataCenter.roleData.name then
		OperateAlert.showLangValue(300026)
		return
	end

	if DataCenter.loginData:checkRoleNameIsInvalid(name) then
		return
	end
	
	Lua_ProxyManager.getProxy("Lua_RoleProxy"):sRename(name)
end