Lua_SetUpWindow = class("Lua_SetUpWindow", Lua_Window)
function Lua_SetUpWindow:ctor()
	self:superCall("ctor")

	self.windowName = "Lua_SetUpWindow"
	self.skinName = "SetUpWindow_skin"
	self.showBlackMask = true
	self.isClickClose = true
end

function Lua_SetUpWindow:buildShowItem()
	self:superCall("buildShowItem")

	self.playerPrefsUtil = PlayerPrefsUtil.instance
	self.sliderMusic = Lua_SliderProgressBar.new(self.content, "role_atlas", "xui_grxx_tipsprogress_1_b", "xui_grxx_tipsprogress_1_f", "xui_grxx_button_1", 470, 30)
	self.sliderMusic:setLocation(50, 230.5, 0)
	self.sliderMusic:setValue(PlayerPrefsUtil.instance.musicVolume, 0, 100)
	self.sliderMusic:setCallBack(self, self.updateMusicVolume, self.updateMusicVolumeEnd)

	self.sliderSound = Lua_SliderProgressBar.new(self.content, "role_atlas", "xui_grxx_tipsprogress_1_b", "xui_grxx_tipsprogress_1_f", "xui_grxx_button_1", 470, 30)
	self.sliderSound:setLocation(50, 169, 0)
	self.sliderSound:setValue(PlayerPrefsUtil.instance.soundVolume, 0, 100)
	self.sliderSound:setCallBack(self, self.updateSoundVolume, self.updateSoundVolumeEnd)

	self.cbHighQuality:addBoxChange(self, self.onHighQualityChange)--高品质
	self.cbSmooth:addBoxChange(self, self.onSmoothChange)--流畅
	self.cbPowerSaving:addBoxChange(self, self.onPowerSavingChange)--省电

	self.cbHighReso:addBoxChange(self, self.onRenderScaleHight)--高分辨率
	self.cbMiddleReso:addBoxChange(self, self.onRenderScaleMid)--中分辨率
	self.cbLowReso:addBoxChange(self, self.onRenderScaleLow)--低分辨率

	self.cbOpenAnti:addBoxChange(self, self.onMSAAOpen)--开启抗锯齿
	self.cbCloseAnti:addBoxChange(self, self.onMSAAClose)--关闭抗锯齿

	self.btnExit:addClickFuntion(self, self.onBtnExitClick)
	self.btnSwitch:addClickFuntion(self, self.onBtnSwitchClick)

	self:updateShowInfo()
	self:updateQuality()
	self:updateRenderScale()
	self:updateMSAA()
end

function Lua_SetUpWindow:dispose()
	self.playerPrefsUtil = nil
	if self.sliderMusic ~= nil then
		self.sliderMusic:dispose()
		self.sliderMusic = nil
	end
	if self.sliderSound ~= nil then
		self.sliderSound:dispose()
		self.sliderSound = nil
	end
	self:superCall("dispose")
end

function Lua_SetUpWindow:updateShowInfo()
	local arr = string.split(DataCenter.roleData.server_name, "#")
	if arr == nil or arr:getSize() <= 0 then
		self.serverName.text = DataCenter.roleData.server_name
	else
		self.serverName.text = LanUtil.formateStr(300006, arr[2])
	end
	self.serverName:resetSize()
	self.serverBg:SetDimensions(self.serverName.width + 30, 48)
end

function Lua_SetUpWindow:updateMusicVolume(count)
	PlayerPrefsUtil.instance.musicVolume = count
end

function Lua_SetUpWindow:updateMusicVolumeEnd(count)
	self:sendSetUp()
end

function Lua_SetUpWindow:updateSoundVolume(count)
	PlayerPrefsUtil.instance.soundVolume = count
end

function Lua_SetUpWindow:updateSoundVolumeEnd(count)
	self:sendSetUp()
end

function Lua_SetUpWindow:sendSetUp()
	local tab = {}
	tab[Lua_SetUpDefine.quality_lv] = PlayerPrefsUtil.instance:GetUnInt(Lua_SetUpDefine.quality_lv, -1)
	tab[Lua_SetUpDefine.music_volume] = PlayerPrefsUtil.instance.musicVolume
	tab[Lua_SetUpDefine.sound_volume] = PlayerPrefsUtil.instance.soundVolume
	tab[Lua_SetUpDefine.quality_renderscale] = PlayerPrefsUtil.instance:GetUnInt(Lua_SetUpDefine.quality_renderscale, -1)
	tab[Lua_SetUpDefine.quality_msaa] = PlayerPrefsUtil.instance:GetUnInt(Lua_SetUpDefine.quality_msaa, -1)
	Lua_ProxyManager.getProxy("Lua_RoleProxy"):sSetUp(tab)
end

function Lua_SetUpWindow:onBtnExitClick(go)
	if Lua_PlatformUtil.IsAndroid() == true or Lua_PlatformUtil.IsIPhonePlayer() == true then
		DataCenter.sdkInterface:callSDKInterface(Lua_SDKMessageType.Exit)
	else
		local tipsData = { des = LanUtil.getValue(300019), btnType = 1, owner = self, sureFun = self.onReLogin }
		Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipsData)
	end
end

function Lua_SetUpWindow:onBtnSwitchClick(go)
	if Lua_PlatformUtil.IsAndroid() == true or Lua_PlatformUtil.IsIPhonePlayer() == true then
		self:onReLogin()
	else
		local tipsData = { des = 300020, btnType = 1, owner = self, sureFun = self.onReLogin }
		Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipsData)
	end
end

function Lua_SetUpWindow:onReLogin()
	LoadManager.getInstance():Load(Lua_LoadFileType.IMG, "/images/loading/login_bg.jpg", nil, nil, nil, nil, 999, 30)
	DataCenter.connectionManager:relogin()
end

-- 高性能
function Lua_SetUpWindow:onHighQualityChange(bChange)
	if bChange then
		PlayerPrefsUtil.instance:SetUnInt(Lua_SetUpDefine.quality_lv, 2)
		local msaaCount = DataCenter.deviceQuality:getMsaaCountByIdx(2)
		PlayerPrefsUtil.instance:SetUnInt(Lua_SetUpDefine.quality_msaa, msaaCount)
		local renderScaleIdx = DataCenter.deviceQuality:getRenderScaleIdxByQualityLv(2)
		PlayerPrefsUtil.instance:SetUnInt(Lua_SetUpDefine.quality_renderscale, renderScaleIdx)
		DataCenter.deviceQuality.qualityLevel = 2
		self:updateQuality(2)
		self:updateRenderScale(renderScaleIdx)
		self:updateMSAA(msaaCount)
		self:sendSetUp()
	else
		OperateAlert.showLangValue(300018)
		self.cbHighQuality.selected = true
	end
end

-- 流畅
function Lua_SetUpWindow:onSmoothChange(bChange)
	if bChange then
		PlayerPrefsUtil.instance:SetUnInt(Lua_SetUpDefine.quality_lv, 1)
		local msaaCount = DataCenter.deviceQuality:getMsaaCountByIdx(1)
		PlayerPrefsUtil.instance:SetUnInt(Lua_SetUpDefine.quality_msaa, msaaCount)
		local renderScaleIdx = DataCenter.deviceQuality:getRenderScaleIdxByQualityLv(1)
		PlayerPrefsUtil.instance:SetUnInt(Lua_SetUpDefine.quality_renderscale, renderScaleIdx)
		DataCenter.deviceQuality.qualityLevel = 1
		self:updateQuality(1)
		self:updateRenderScale(renderScaleIdx)
		self:updateMSAA(msaaCount)
		self:sendSetUp()
	else
		OperateAlert.showLangValue(300018)
		self.cbSmooth.selected = true
	end
end

-- 省电
function Lua_SetUpWindow:onPowerSavingChange(bChange)
	if bChange then
		PlayerPrefsUtil.instance:SetUnInt(Lua_SetUpDefine.quality_lv, 0)
		local msaaCount = DataCenter.deviceQuality:getMsaaCountByIdx(0)
		PlayerPrefsUtil.instance:SetUnInt(Lua_SetUpDefine.quality_msaa, msaaCount)
		local renderScaleIdx = DataCenter.deviceQuality:getRenderScaleIdxByQualityLv(0)
		PlayerPrefsUtil.instance:SetUnInt(Lua_SetUpDefine.quality_renderscale, renderScaleIdx)
		DataCenter.deviceQuality.qualityLevel = 0
		self:updateQuality(0)
		self:updateRenderScale(renderScaleIdx)
		self:updateMSAA(msaaCount)
		self:sendSetUp()
	else
		OperateAlert.showLangValue(300018)
		self.cbPowerSaving.selected = true
	end
end

-- 高分辨率
function Lua_SetUpWindow:onRenderScaleHight(bChange)
	if bChange then
		PlayerPrefsUtil.instance:SetUnInt(Lua_SetUpDefine.quality_renderscale, 1)
		DataCenter.deviceQuality:updateRenderScale()
		self:updateRenderScale(1)
		self:sendSetUp()
	end
end

-- 中分辨率
function Lua_SetUpWindow:onRenderScaleMid(bChange)
	if bChange then
		PlayerPrefsUtil.instance:SetUnInt(Lua_SetUpDefine.quality_renderscale, 2)
		DataCenter.deviceQuality:updateRenderScale()
		self:updateRenderScale(2)
		self:sendSetUp()
	end
end

-- 低分辨率
function Lua_SetUpWindow:onRenderScaleLow(bChange)
	if bChange then
		PlayerPrefsUtil.instance:SetUnInt(Lua_SetUpDefine.quality_renderscale, 3)
		DataCenter.deviceQuality:updateRenderScale()
		self:updateRenderScale(3)
		self:sendSetUp()
	end
end

-- 开启抗锯齿
function Lua_SetUpWindow:onMSAAOpen(bChange)
	if bChange then
		local qualityLv = DataCenter.deviceQuality.qualityLevel
		local msaa = DataCenter.deviceQuality:getMsaaCountByIdx(qualityLv)
		if msaa <= 0 then msaa = 2 end
		PlayerPrefsUtil.instance:SetUnInt(Lua_SetUpDefine.quality_msaa, msaa)
    	DataCenter.deviceQuality:updateMSAA()
		self:updateMSAA(msaa)
	end
end

-- 关闭抗锯齿
function Lua_SetUpWindow:onMSAAClose(bChange)
	if bChange then
		PlayerPrefsUtil.instance:SetUnInt(Lua_SetUpDefine.quality_msaa, 0)	
		DataCenter.deviceQuality:updateMSAA()
		self:updateMSAA(0)
	end
end

function Lua_SetUpWindow:updateQuality(qualityLv)
	if qualityLv == nil then qualityLv = DataCenter.deviceQuality.qualityLevel end
	self.cbHighQuality.selected = qualityLv >= 2--高品质
	self.cbSmooth.selected = qualityLv == 1--流畅
	self.cbPowerSaving.selected = qualityLv == 0--省电
end

function Lua_SetUpWindow:updateRenderScale(idx)
	if idx == nil then 
		idx = PlayerPrefsUtil.instance:GetUnInt(Lua_SetUpDefine.quality_renderscale, -1)
		if idx == -1 then
			local qualityLevel = DataCenter.deviceQuality.qualityLevel
			idx = DataCenter.deviceQuality:getRenderScaleIdxByQualityLv(qualityLevel)
		end
	end
	self.cbHighReso.selected = idx == 1--高分辨率
	self.cbMiddleReso.selected = idx == 2--中分辨率
	self.cbLowReso.selected = idx > 2--低分辨率
end

function Lua_SetUpWindow:updateMSAA(msaa)
	if msaa == nil then 
		msaa = PlayerPrefsUtil.instance:GetUnInt(Lua_SetUpDefine.quality_msaa, -1)
		if msaa == -1 then
			msaa = DataCenter.deviceQuality.msaaCount
		end 
	end
	self.cbOpenAnti.selected = msaa > 0--开启抗锯齿
	self.cbCloseAnti.selected = msaa <= 0--关闭抗锯齿
end